@@ -1,7 +1,7 @@
 package Test::WithDB::SQLite;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-09-27'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -33,9 +33,11 @@ sub _read_config {
 
     $cfg->{sqlite_db_dir} //= do {
         require File::Temp;
-        File::Temp::tempdir(CLEANUP=>1);
+        File::Temp::tempdir(CLEANUP=>$ENV{TWDB_KEEP_TEMP_DBS} ? 0:1);
     };
 
+    Test::More::note("Will be creating test SQLite databases in '$cfg->{sqlite_db_dir}'");
+
     $self->{_config} = $cfg;
 }
 
@@ -54,7 +56,7 @@ Test::WithDB::SQLite - A subclass of Test::WithDB that provide defaults for SQLi
 
 =head1 VERSION
 
-This document describes version 0.06 of Test::WithDB::SQLite (from Perl distribution Test-WithDB), released on 2015-08-18.
+This document describes version 0.07 of Test::WithDB::SQLite (from Perl distribution Test-WithDB), released on 2015-09-27.
 
 =head1 SYNOPSIS
 
